@@ -1,10 +1,8 @@
-#import sys
-#sys.path.insert(1, '/Users/caitlin/Documents/Math/PIC16B/pic16bproject')
-#pde-simulation==0.0.1
-from pde_imulation import transport_equation as te
-#from pde_simulation import wave_equation as we
-#from pde_simulation import heat_equation as he
-#from pde_simulation import burgers as be
+import sys
+sys.path.insert(1, '/Users/caitlin/Documents/Math/PIC16B/pic16bproject')
+from PdeSimulation import wave_equation as we
+from PdeSimulation  import heat_equation as he
+from PdeSimulation  import burgers as be
 import numpy as np
 import matplotlib.pyplot as plt
 plt.rcParams['animation.ffmpeg_path'] = '/Users/caitlin/opt/anaconda3/bin/ffmpeg'
@@ -19,7 +17,10 @@ def sine(x):
     return np.sin(2*x*np.pi)
 def Gaussian_2d(x,y):
 	return 0.8*np.exp(-700*((x-1)**2+(y-0)**2))+0.8*np.exp(-700*((x-0)**2+(y-1)**2))
-te.solution(f,"animation")
+def Gaussian_2d_2(x,y):
+    return 0.8*np.exp(-70*((x-0.5)**2+(y-0.5)**2))
+#te.solution(f,"animation")
+he.solution(Gaussian_2d_2,2,)
 #we.solution(sine,1,"3d")
 #we.solution(Gaussian_2d,2)
 #be.solution("shock")
\ No newline at end of file
